import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
 'https://gist.githubusercontent.com/Amanullah007/18bbe107e956bca1b77ab321d65f0833/raw/3b1ba9160001e1422f6a03a86af8f1d60e91ed90/tokyo.csv';
const width = 966;
const height = 490;
const margin = { top: 20, right: 30, bottom: 50, left: 200 };

const App = () => {
  const [CountryData, setelectionData] = useState([]);

  useEffect(() => {
    csv(csvUrl).then(CountryData => {
      CountryData.sort((data1, data2) => data2.Gold-data1.Gold);
      if (CountryData) {
        setelectionData(CountryData.slice(0, 10));
      }
    });
  }, []);
  
  if (!CountryData) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(CountryData.map(data => data.Country))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(CountryData, data => data.Gold)])
    .range([0, innerWidth]);
  
  const colors = ['#A803D2', '#F572E3', '#C8AFE7', '#1092A3', '#6BFE46', '#A38917', '#2C9338', '#934304', '#59D032', '#E19425'];

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="blue" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {CountryData.map((data, index) => (
          <rect
            key={data.Country}
            x={0}
            y={yScale(data.Country)}
            width={xScale(data.Gold)}
            height={yScale.bandwidth()}
            fill={colors[index]}
            stroke="#006600"
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);